import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:screen_plus/screen_plus.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        // This is the theme of your application.
        //
        // Try running your application with "flutter run". You'll see the
        // application has a blue toolbar. Then, without quitting the app, try
        // changing the primarySwatch below to Colors.green and then invoke
        // "hot reload" (press "r" in the console where you ran "flutter run",
        // or simply save your changes to "hot reload" in a Flutter IDE).
        // Notice that the counter didn't reset back to zero; the application
        // is not restarted.
        primarySwatch: Colors.blue,
      ),
      home: const MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({Key? key, required this.title}) : super(key: key);

  // This widget is the home page of your application. It is stateful, meaning
  // that it has a State object (defined below) that contains fields that affect
  // how it looks.

  // This class is the configuration for the state. It holds the values (in this
  // case the title) provided by the parent (in this case the App widget) and
  // used by the build method of the State. Fields in a Widget subclass are
  // always marked "final".

  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  int _counter = 0;
  double? brightnessValue;

  void _incrementCounter() {
    setState(() {
      // This call to setState tells the Flutter framework that something has
      // changed in this State, which causes it to rerun the build method below
      // so that the display can reflect the updated values. If we changed
      // _counter without calling setState(), then the build method would not be
      // called again, and so nothing would appear to happen.
      _counter++;
    });
  }

  @override
  Widget build(BuildContext context) {
    // This method is rerun every time setState is called, for instance as done
    // by the _incrementCounter method above.
    //
    // The Flutter framework has been optimized to make rerunning build methods
    // fast, so that you can just rebuild anything that needs updating rather
    // than having to individually change instances of widgets.
    return Scaffold(
      appBar: AppBar(
        // Here we take the value from the MyHomePage object that was created by
        // the App.build method, and use it to set our appbar title.
        title: Text(widget.title),
      ),
      body: Center(
        // Center is a layout widget. It takes a single child and positions it
        // in the middle of the parent.
        child: Column(
          // Column is also a layout widget. It takes a list of children and
          // arranges them vertically. By default, it sizes itself to fit its
          // children horizontally, and tries to be as tall as its parent.
          //
          // Invoke "debug painting" (press "p" in the console, choose the
          // "Toggle Debug Paint" action from the Flutter Inspector in Android
          // Studio, or the "Toggle Debug Paint" command in Visual Studio Code)
          // to see the wireframe for each widget.
          //
          // Column has various properties to control how it sizes itself and
          // how it positions its children. Here we use mainAxisAlignment to
          // center the children vertically; the main axis here is the vertical
          // axis because Columns are vertical (the cross axis would be
          // horizontal).
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            CupertinoButton(
                child: const Text('点亮屏幕'),
                onPressed: () {
                  var status = ScreenPlus().getBrightnessStatus();
                  // ignore: avoid_print
                  print(status);
                  if (brightnessValue != null) {
                    ScreenPlus().setBrightness(brightnessValue!);
                  }
                  setState(() {});
                }),
            CupertinoButton(
                child: const Text('降低屏幕亮度'),
                onPressed: () async {
                  // fetch current brightness value
                  double brightness = await ScreenPlus().brightness();
                  brightnessValue = brightness;
                  ScreenPlus().setBrightness(0);
                  setState(() {});
                }),
            CupertinoButton(
                child: const Text('设置屏幕为常亮'),
                onPressed: () async {
                  // fetch current brightness value
                  ScreenPlus().setScreenWake(true);
                  setState(() {});
                }),
            CupertinoButton(
                child: const Text('设置屏幕为非常亮'),
                onPressed: () async {
                  // fetch current brightness value
                  ScreenPlus().setScreenWake(false);
                  setState(() {});
                }),
            Text(
              '当前亮度值：$brightnessValue',
              style: Theme.of(context).textTheme.headline4,
            ),
            FutureBuilder(
              builder: (BuildContext context, AsyncSnapshot<bool> snapshot) {
                if (snapshot.connectionState == ConnectionState.waiting) {
                  return Text("获取当前屏幕状态ing");
                } else if (snapshot.connectionState == ConnectionState.done) {
                  var currentData = snapshot.data;
                  return Text("当前屏幕状态$currentData");
                } else {
                  return Text("获取当前屏幕状态ing");
                }
              },
              future: _fetchLightStatus(),
              initialData: true,
            )
          ],
        ),
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: _incrementCounter,
        tooltip: 'Increment',
        child: const Icon(Icons.brightness_high),
      ), // This trailing comma makes auto-formatting nicer for build methods.
    );
  }

  Future<bool> _fetchLightStatus() async {
    return ScreenPlus().getBrightnessStatus();
  }
}
